==> generic-plugin-5.1.4-sources.jar: com/xebialabs/deployit/plugin/generic/ci/BaseGenericContainer.java <==
package com.xebialabs.deployit.plugin.generic.ci;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionContext;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseContainer;
import com.xebialabs.deployit.plugin.generic.step.InspectScriptExecutionStep;
import com.xebialabs.deployit.plugin.overthere.Host;

import static com.google.common.base.Strings.emptyToNull;
import static com.google.common.collect.Lists.newArrayList;
import static com.google.common.collect.Maps.newHashMap;
import static com.google.common.collect.Sets.newHashSet;
import static com.xebialabs.deployit.plugin.generic.freemarker.ConfigurationHolder.resolveExpression;

@SuppressWarnings("serial")
public abstract class BaseGenericContainer extends BaseContainer implements GenericContainer {

    private Map<String, Object> freeMarkerContext = Collections.singletonMap("container", (Object) this);

    @Property(required = false, category = "Deployment", label = "Alternative Stop/Start/Restart Connection Settings", description = "If set, the connection settings to use to connect to the target system to execute start, stop, restart etc. operations for the container.")
    private Host stopStartRestartConnection;

    @Property(required = false, hidden = true, description = "Classpath to the script used to start the generic container.")
    private String startScript;

    @Property(defaultValue = "90", hidden = true, description = "The order of the start container step in the step list.")
    private int startOrder;

    @Property(defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container start action.")
    private int startWaitTime;

    @Property(required = false, hidden = true, description = "Classpath to the script used to stop the generic container.")
    private String stopScript;

    @Property(defaultValue = "10", hidden = true, description = "The order of the stop container step in the step list.")
    private int stopOrder;

    @Property(defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container stop action.")
    private int stopWaitTime;

    @Property(required = false, hidden = true, description = "Classpath to the script used to restart the generic container.")
    private String restartScript;

    @Property(defaultValue = "90", hidden = true, description = "The order of the restart container step in the step list.")
    private int restartOrder;

    @Property(required = true, defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container restart action.")
    private int restartWaitTime;

    @Property(required = false, description = "Environment variables for container", label = "Environment Variables")
    private Map<String, String> envVars = newHashMap();

    @Property(required = false, hidden = true, description = "Classpath to the script used to inspect the generic container.")
    private String inspectScript;

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the inspect script.")
    private Set<String> inspectClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the inspect script."
        + "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> inspectTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the start script.")
    private Set<String> startClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the start script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> startTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the stop script.")
    private Set<String> stopClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the stop script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> stopTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the restart script.")
    private Set<String> restartClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the restart script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> restartTemplateClasspathResources = newHashSet();

    public List<Step> controlTaskDispatch(String name, Map<String,String> args) {
        return ControlTaskDelegate.executedScriptDelegate(this, name, args, null);
    }

    @Inspect
    public void inspectContainer(InspectionContext ctx) {
        if (emptyToNull(getInspectScript()) != null) {
            InspectScriptExecutionStep step = new InspectScriptExecutionStep(this, getInspectScript(), getHost(), freeMarkerContext, "Inspect " + this);
            step.setTemplateClasspathResources(newArrayList(getInspectTemplateClasspathResources()));
            step.setClasspathResources(newArrayList(getInspectClasspathResources()));
            ctx.addStep(step);
        }
    }

    public Host getStopStartRestartConnection() {
        return stopStartRestartConnection;
    }

    public void setStopStartRestartConnection(Host stopStartRestartConnection) {
        this.stopStartRestartConnection = stopStartRestartConnection;
    }

    public String getStartScript() {
        return resolveExpression(startScript, freeMarkerContext);
    }

    public void setStartScript(String startScript) {
        this.startScript = startScript;
    }

    public int getStartOrder() {
        return startOrder;
    }

    public void setStartOrder(int startOrder) {
        this.startOrder = startOrder;
    }

    public int getStartWaitTime() {
        return startWaitTime;
    }

    public void setStartWaitTime(int startWaitTime) {
        this.startWaitTime = startWaitTime;
    }

    public String getStopScript() {
        return resolveExpression(stopScript, freeMarkerContext);
    }

    public void setStopScript(String stopScript) {
        this.stopScript = stopScript;
    }

    public int getStopOrder() {
        return stopOrder;
    }

    public void setStopOrder(int stopOrder) {
        this.stopOrder = stopOrder;
    }

    public int getStopWaitTime() {
        return stopWaitTime;
    }

    public void setStopWaitTime(int stopWaitTime) {
        this.stopWaitTime = stopWaitTime;
    }

    public String getRestartScript() {
        return resolveExpression(restartScript, freeMarkerContext);
    }

    public void setRestartScript(String restartScript) {
        this.restartScript = restartScript;
    }

    public int getRestartOrder() {
        return restartOrder;
    }

    public void setRestartOrder(int restartOrder) {
        this.restartOrder = restartOrder;
    }

    public int getRestartWaitTime() {
        return restartWaitTime;
    }

    public void setRestartWaitTime(int restartWaitTime) {
        this.restartWaitTime = restartWaitTime;
    }

    public Map<String, String> getEnvVars() {
        return envVars;
    }

    public void setEnvVars(Map<String, String> envVars) {
        this.envVars = envVars;
    }

    public String getInspectScript() {
        return resolveExpression(inspectScript, freeMarkerContext);
    }

    public void setInspectScript(String inspectScript) {
        this.inspectScript = inspectScript;
    }

    public Set<String> getInspectClasspathResources() {
        return resolveExpression(inspectClasspathResources, freeMarkerContext);
    }

    public void setInspectClasspathResources(Set<String> inspectClasspathResources) {
        this.inspectClasspathResources = inspectClasspathResources;
    }

    public Set<String> getInspectTemplateClasspathResources() {
        return resolveExpression(inspectTemplateClasspathResources, freeMarkerContext);
    }

    public void setInspectTemplateClasspathResources(Set<String> inspectTemplateClasspathResources) {
        this.inspectTemplateClasspathResources = inspectTemplateClasspathResources;
    }

    public Set<String> getStartClasspathResources() {
        return startClasspathResources;
    }

    public void setStartClasspathResources(final Set<String> startClasspathResources) {
        this.startClasspathResources = startClasspathResources;
    }

    public Set<String> getStartTemplateClasspathResources() {
        return startTemplateClasspathResources;
    }

    public void setStartTemplateClasspathResources(final Set<String> startTemplateClasspathResources) {
        this.startTemplateClasspathResources = startTemplateClasspathResources;
    }

    public Set<String> getStopClasspathResources() {
        return stopClasspathResources;
    }

    public void setStopClasspathResources(final Set<String> stopClasspathResources) {
        this.stopClasspathResources = stopClasspathResources;
    }

    public Set<String> getStopTemplateClasspathResources() {
        return stopTemplateClasspathResources;
    }

    public void setStopTemplateClasspathResources(final Set<String> stopTemplateClasspathResources) {
        this.stopTemplateClasspathResources = stopTemplateClasspathResources;
    }

    public Set<String> getRestartClasspathResources() {
        return restartClasspathResources;
    }

    public void setRestartClasspathResources(final Set<String> restartClasspathResources) {
        this.restartClasspathResources = restartClasspathResources;
    }

    public Set<String> getRestartTemplateClasspathResources() {
        return restartTemplateClasspathResources;
    }

    public void setRestartTemplateClasspathResources(final Set<String> restartTemplateClasspathResources) {
        this.restartTemplateClasspathResources = restartTemplateClasspathResources;
    }
}

==> generic-plugin-23.3.6-sources.jar: com/xebialabs/deployit/plugin/generic/ci/BaseGenericContainer.java <==
package com.xebialabs.deployit.plugin.generic.ci;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionContext;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseContainer;
import com.xebialabs.deployit.plugin.generic.step.InspectScriptExecutionStep;
import com.xebialabs.deployit.plugin.overthere.Host;

import static com.google.common.base.Strings.emptyToNull;
import static com.google.common.collect.Lists.newArrayList;
import static com.google.common.collect.Maps.newHashMap;
import static com.google.common.collect.Sets.newHashSet;
import static com.xebialabs.deployit.plugin.generic.freemarker.ConfigurationHolder.resolveExpression;

@SuppressWarnings("serial")
public abstract class BaseGenericContainer extends BaseContainer implements GenericContainer {

    private transient final Map<String, Object> freeMarkerContext = Collections.singletonMap("container", this);

    @Property(required = false, category = "Deployment", label = "Alternative Stop/Start/Restart Connection Settings", description = "If set, the connection settings to use to connect to the target system to execute start, stop, restart etc. operations for the container.")
    private Host stopStartRestartConnection;

    @Property(required = false, hidden = true, description = "Classpath to the script used to start the generic container.")
    private String startScript;

    @Property(defaultValue = "90", hidden = true, description = "The order of the start container step in the step list.")
    private int startOrder;

    @Property(defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container start action.")
    private int startWaitTime;

    @Property(required = false, hidden = true, description = "Classpath to the script used to stop the generic container.")
    private String stopScript;

    @Property(defaultValue = "10", hidden = true, description = "The order of the stop container step in the step list.")
    private int stopOrder;

    @Property(defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container stop action.")
    private int stopWaitTime;

    @Property(required = false, hidden = true, description = "Classpath to the script used to restart the generic container.")
    private String restartScript;

    @Property(defaultValue = "90", hidden = true, description = "The order of the restart container step in the step list.")
    private int restartOrder;

    @Property(required = true, defaultValue = "0", hidden = true, description = "The time to wait in seconds for a container restart action.")
    private int restartWaitTime;

    @Property(required = false, description = "Environment variables for container", label = "Environment Variables")
    private Map<String, String> envVars = newHashMap();

    @Property(required = false, hidden = true, description = "Classpath to the script used to inspect the generic container.")
    private String inspectScript;

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the inspect script.")
    private Set<String> inspectClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the inspect script."
        + "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> inspectTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the start script.")
    private Set<String> startClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the start script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> startTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the stop script.")
    private Set<String> stopClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the stop script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> stopTemplateClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional classpath resources that should be uploaded to the working directory before executing the restart script.")
    private Set<String> restartClasspathResources = newHashSet();

    @Property(hidden = true, required = false, description = "Additional template classpath resources that should be uploaded to the working directory before executing the restart script." +
            "The template is first rendered and the rendered content copied to a file, with the same name as the template, in the working directory.")
    private Set<String> restartTemplateClasspathResources = newHashSet();

    public List<Step> controlTaskDispatch(String name, Map<String,String> args) {
        return ControlTaskDelegate.executedScriptDelegate(this, name, args, null);
    }

    @Inspect
    public void inspectContainer(InspectionContext ctx) {
        if (emptyToNull(getInspectScript()) != null) {
            InspectScriptExecutionStep step = new InspectScriptExecutionStep(this, getInspectScript(), getHost(), freeMarkerContext, "Inspect " + this);
            step.setTemplateClasspathResources(newArrayList(getInspectTemplateClasspathResources()));
            step.setClasspathResources(newArrayList(getInspectClasspathResources()));
            ctx.addStep(step);
        }
    }

    public Host getStopStartRestartConnection() {
        return stopStartRestartConnection;
    }

    public void setStopStartRestartConnection(Host stopStartRestartConnection) {
        this.stopStartRestartConnection = stopStartRestartConnection;
    }

    public String getStartScript() {
        return resolveExpression(startScript, freeMarkerContext);
    }

    public void setStartScript(String startScript) {
        this.startScript = startScript;
    }

    public int getStartOrder() {
        return startOrder;
    }

    public void setStartOrder(int startOrder) {
        this.startOrder = startOrder;
    }

    public int getStartWaitTime() {
        return startWaitTime;
    }

    public void setStartWaitTime(int startWaitTime) {
        this.startWaitTime = startWaitTime;
    }

    public String getStopScript() {
        return resolveExpression(stopScript, freeMarkerContext);
    }

    public void setStopScript(String stopScript) {
        this.stopScript = stopScript;
    }

    public int getStopOrder() {
        return stopOrder;
    }

    public void setStopOrder(int stopOrder) {
        this.stopOrder = stopOrder;
    }

    public int getStopWaitTime() {
        return stopWaitTime;
    }

    public void setStopWaitTime(int stopWaitTime) {
        this.stopWaitTime = stopWaitTime;
    }

    public String getRestartScript() {
        return resolveExpression(restartScript, freeMarkerContext);
    }

    public void setRestartScript(String restartScript) {
        this.restartScript = restartScript;
    }

    public int getRestartOrder() {
        return restartOrder;
    }

    public void setRestartOrder(int restartOrder) {
        this.restartOrder = restartOrder;
    }

    public int getRestartWaitTime() {
        return restartWaitTime;
    }

    public void setRestartWaitTime(int restartWaitTime) {
        this.restartWaitTime = restartWaitTime;
    }

    public Map<String, String> getEnvVars() {
        return envVars;
    }

    public void setEnvVars(Map<String, String> envVars) {
        this.envVars = envVars;
    }

    public String getInspectScript() {
        return resolveExpression(inspectScript, freeMarkerContext);
    }

    public void setInspectScript(String inspectScript) {
        this.inspectScript = inspectScript;
    }

    public Set<String> getInspectClasspathResources() {
        return resolveExpression(inspectClasspathResources, freeMarkerContext);
    }

    public void setInspectClasspathResources(Set<String> inspectClasspathResources) {
        this.inspectClasspathResources = inspectClasspathResources;
    }

    public Set<String> getInspectTemplateClasspathResources() {
        return resolveExpression(inspectTemplateClasspathResources, freeMarkerContext);
    }

    public void setInspectTemplateClasspathResources(Set<String> inspectTemplateClasspathResources) {
        this.inspectTemplateClasspathResources = inspectTemplateClasspathResources;
    }

    public Set<String> getStartClasspathResources() {
        return startClasspathResources;
    }

    public void setStartClasspathResources(final Set<String> startClasspathResources) {
        this.startClasspathResources = startClasspathResources;
    }

    public Set<String> getStartTemplateClasspathResources() {
        return startTemplateClasspathResources;
    }

    public void setStartTemplateClasspathResources(final Set<String> startTemplateClasspathResources) {
        this.startTemplateClasspathResources = startTemplateClasspathResources;
    }

    public Set<String> getStopClasspathResources() {
        return stopClasspathResources;
    }

    public void setStopClasspathResources(final Set<String> stopClasspathResources) {
        this.stopClasspathResources = stopClasspathResources;
    }

    public Set<String> getStopTemplateClasspathResources() {
        return stopTemplateClasspathResources;
    }

    public void setStopTemplateClasspathResources(final Set<String> stopTemplateClasspathResources) {
        this.stopTemplateClasspathResources = stopTemplateClasspathResources;
    }

    public Set<String> getRestartClasspathResources() {
        return restartClasspathResources;
    }

    public void setRestartClasspathResources(final Set<String> restartClasspathResources) {
        this.restartClasspathResources = restartClasspathResources;
    }

    public Set<String> getRestartTemplateClasspathResources() {
        return restartTemplateClasspathResources;
    }

    public void setRestartTemplateClasspathResources(final Set<String> restartTemplateClasspathResources) {
        this.restartTemplateClasspathResources = restartTemplateClasspathResources;
    }
}
